@@ -54,6 +54,7 @@ import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.HasRowDragRestrictions;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
@@ -98,7 +99,8 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
                        final boolean isOnlyVisualChangeAllowed,
                        final int nesting,
                        final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
-                       final ValueAndDataTypePopoverView.Presenter headerEditor) {
+                       final ValueAndDataTypePopoverView.Presenter headerEditor,
+                       final ReadOnlyProvider readOnlyProvider) {
         super(parent,
               nodeUUID,
               hasExpression,
@@ -118,7 +120,8 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
               listSelector,
               translationService,
               isOnlyVisualChangeAllowed,
-              nesting);
+              nesting,
+              readOnlyProvider);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
         this.headerEditor = headerEditor;
 
