@@ -52,6 +52,9 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String ExpressionEditor_InvocationType = "ExpressionEditor.InvocationType";
 
+    @TranslationKey(defaultValue = "")
+    public static final String ExpressionEditor_ListType = "ExpressionEditor.ListType";
+
     @TranslationKey(defaultValue = "")
     public static final String ExpressionEditor_Clear = "ExpressionEditor.Clear";
 
@@ -130,6 +133,21 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String InvocationEditor_EnterFunction = "InvocationEditor.EnterFunction";
 
+    @TranslationKey(defaultValue = "")
+    public static final String ListEditor_HeaderRows = "ListEditor.HeaderRows";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ListEditor_InsertRowAbove = "ListEditor.InsertRowAbove";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ListEditor_InsertRowBelow = "ListEditor.InsertRowBelow";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ListEditor_DeleteRow = "ListEditor.DeleteRow";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ListEditor_EditExpression = "ListEditor.EditExpression";
+
     @TranslationKey(defaultValue = "")
     public static final String FunctionEditor_FEEL = "FunctionEditor.FEEL";
 
@@ -154,9 +172,6 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String FunctionEditor_SelectFunctionKind = "FunctionEditor.SelectFunctionKind";
 
-    @TranslationKey(defaultValue = "")
-    public static final String DecisionTableEditor_DescriptionColumnHeader = "DecisionTableEditor.DescriptionColumnHeader";
-
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_DecisionRuleHeader = "DecisionTableEditor.DecisionRuleHeader";
 
@@ -187,6 +202,18 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_OutputClauseHeader = "DecisionTableEditor.OutputClauseHeader";
 
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_RuleAnnotationClauseHeader = "DecisionTableEditor.RuleAnnotationClauseHeader";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_InsertRuleAnnotationClauseLeft = "DecisionTableEditor.InsertRuleAnnotationClauseLeft";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_InsertRuleAnnotationClauseRight = "DecisionTableEditor.InsertRuleAnnotationClauseRight";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_DeleteRuleAnnotationClause = "DecisionTableEditor.DeleteRuleAnnotationClause";
+
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_InsertOutputClauseLeft = "DecisionTableEditor.InsertOutputClauseLeft";
 
@@ -214,6 +241,12 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_BuiltinAggregatorLabel = "DecisionTableEditor.BuiltinAggregatorLabel";
 
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_EnterAnnotation =  "DecisionTableEditor.EnterAnnotation";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_InputClauseColumnHeaderMetaData_ValueLabel = "DecisionTableEditor.InputClauseColumnHeaderMetaData.ValueLabel";
+
     @TranslationKey(defaultValue = "")
     public static final String UndefinedExpressionEditor_SelectorTitle = "UndefinedExpressionEditor.SelectorTitle";
 
@@ -274,6 +307,9 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String DataTypeWithFieldsWarningMessage_RegularMessage = "DataTypeWithFieldsWarningMessage.RegularMessage";
 
+    @TranslationKey(defaultValue = "")
+    public static final String DataTypeSuccessfullyImportedMessage_StrongMessage = "DataTypeSuccessfullyImportedMessage.RegularMessage";
+
     @TranslationKey(defaultValue = "")
     public static final String ReferencedDataTypeWarningMessage_StrongMessage = "ReferencedDataTypeWarningMessage.StrongMessage";
 
@@ -290,16 +326,25 @@ public class DMNEditorConstants {
     public static final String DataTypeConstraintView_ConstraintsTooltip = "DataTypeConstraintView.ConstraintsTooltip";
 
     @TranslationKey(defaultValue = "")
-    public static final String DataTypeListItemView_List = "DataTypeListItemView.List";
+    public static final String DataTypeConstraintView_AddConstraints = "DataTypeConstraintView.AddConstraints";
 
     @TranslationKey(defaultValue = "")
     public static final String DataTypeListItemView_ArrowKeysTooltip = "DataTypeListItemView.ArrowKeysTooltip";
 
     @TranslationKey(defaultValue = "")
-    public static final String SmallSwitchComponentView_Yes = "SmallSwitchComponentView.Yes";
+    public static final String DataTypeListItemView_Edit = "DataTypeListItemView.Edit";
 
     @TranslationKey(defaultValue = "")
-    public static final String SmallSwitchComponentView_No = "SmallSwitchComponentView.No";
+    public static final String DataTypeListItemView_Save = "DataTypeListItemView.Save";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DataTypeListItemView_AddRowBelow = "DataTypeListItemView.AddRowBelow";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DataTypeListItemView_Remove = "DataTypeListItemView.Remove";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DataTypeListItemView_Cancel = "DataTypeListItemView.Cancel";
 
     @TranslationKey(defaultValue = "")
     public static final String DataTypesPage_Title = "DataTypesPage.Title";
@@ -439,9 +484,6 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String DMNDocumentationI18n_URLPlaceholder = "DMNDocumentationI18n.URLPlaceholder";
 
-    @TranslationKey(defaultValue = "")
-    public static final String DMNDocumentationFactory_NoFileName = "DMNDocumentationFactory.NoFileName";
-
     @TranslationKey(defaultValue = "")
     public static final String DMNDocumentationFactory_Constraints = "DMNDocumentationFactory.Constraints";
 
@@ -453,4 +495,13 @@ public class DMNEditorConstants {
 
     @TranslationKey(defaultValue = "")
     public static final String DMNPreviewDiagramDock_Title = "DMNPreviewDiagramDock.Title";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionServiceParameters_Inputs = "DecisionServiceParameters.Inputs";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionServiceParameters_Outputs = "DecisionServiceParameters.Outputs";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionServiceParameters_EncapsulatedDecisions = "DecisionServiceParameters.EncapsulatedDecisions";
 }
