@@ -56,11 +56,11 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.dmn.client.editors.types.common.DataType.TOP_LEVEL_PARENT_UUID;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyListOf;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyListOf;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doCallRealMethod;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
@@ -98,6 +98,9 @@ public class DataTypeListTest {
     @Mock
     private DNDDataTypesHandler dndDataTypesHandler;
 
+    @Mock
+    private DataTypeListHighlightHelper highlightHelper;
+
     @Mock
     private IsKogito isKogito;
 
@@ -124,6 +127,7 @@ public class DataTypeListTest {
                                             dndListComponent,
                                             dataTypeStackHash,
                                             dndDataTypesHandler,
+                                            highlightHelper,
                                             isKogito));
         when(listItems.get()).thenReturn(treeGridItem);
     }
@@ -138,6 +142,7 @@ public class DataTypeListTest {
         dataTypeList.setup();
 
         verify(view).init(dataTypeList);
+        verify(highlightHelper).init(dataTypeList);
         verify(view).showImportDataObjectButton();
         verify(dndDataTypesHandler).init(dataTypeList);
         verify(dndListComponent).setOnDropItem(consumer);
@@ -425,7 +430,7 @@ public class DataTypeListTest {
         final DataType dataType = mock(DataType.class);
         final String uuid = "uuid";
 
-        doNothing().when(dataTypeList).removeItem(anyString());
+        doNothing().when(dataTypeList).removeItem(Mockito.<String>any());
         when(dataType.getUUID()).thenReturn(uuid);
 
         dataTypeList.removeItem(dataType);
@@ -1028,6 +1033,7 @@ public class DataTypeListTest {
         when(dataProperty.getType()).thenReturn(propertyType);
 
         when(dataTypeManager.fromNew()).thenReturn(dataTypeManager);
+        when(dataTypeManager.asList(anyBoolean())).thenReturn(dataTypeManager);
         when(dataTypeManager.withType(propertyType)).thenReturn(dataTypeManager);
         when(dataTypeManager.get()).thenReturn(newType);
 
@@ -1035,6 +1041,31 @@ public class DataTypeListTest {
 
         assertEquals(newType, actual);
 
+        verify(dataTypeManager).asList(false);
+        verify(newType).setName(propertyName);
+    }
+
+    @Test
+    public void testCreateNewDataTypeFromPropertyWhenIsList() {
+
+        final DataObjectProperty dataProperty = mock(DataObjectProperty.class);
+        final String propertyName = "name";
+        final String propertyType = "type";
+        final DataType newType = mock(DataType.class);
+        when(dataProperty.getProperty()).thenReturn(propertyName);
+        when(dataProperty.getType()).thenReturn(propertyType);
+        when(dataProperty.isList()).thenReturn(true);
+
+        when(dataTypeManager.fromNew()).thenReturn(dataTypeManager);
+        when(dataTypeManager.asList(anyBoolean())).thenReturn(dataTypeManager);
+        when(dataTypeManager.withType(propertyType)).thenReturn(dataTypeManager);
+        when(dataTypeManager.get()).thenReturn(newType);
+
+        final DataType actual = dataTypeList.createNewDataType(dataProperty);
+
+        assertEquals(newType, actual);
+
+        verify(dataTypeManager).asList(true);
         verify(newType).setName(propertyName);
     }
 
@@ -1153,6 +1184,39 @@ public class DataTypeListTest {
         assertTrue(names.contains(name3));
     }
 
+    @Test
+    public void testHighlightLevelWithDataType() {
+        final DataType dataType = mock(DataType.class);
+        dataTypeList.highlightLevel(dataType);
+        verify(highlightHelper).highlightLevel(dataType);
+    }
+
+    @Test
+    public void testHighlightLevelWithElement() {
+        final Element element = mock(Element.class);
+        dataTypeList.highlightLevel(element);
+        verify(highlightHelper).highlightLevel(element);
+    }
+
+    @Test
+    public void testHighlight() {
+        final Element element = mock(Element.class);
+        dataTypeList.highlight(element);
+        verify(highlightHelper).highlight(element);
+    }
+
+    @Test
+    public void testCleanLevelHighlightClass() {
+        dataTypeList.cleanLevelHighlightClass();
+        verify(highlightHelper).cleanLevelHighlightClass();
+    }
+
+    @Test
+    public void testCleanHighlightClass() {
+        dataTypeList.cleanHighlightClass();
+        verify(highlightHelper).cleanHighlightClass();
+    }
+
     private DataTypeListItem listItem(final DataType dataType) {
         final DataTypeListItem listItem = mock(DataTypeListItem.class);
         when(listItem.getDataType()).thenReturn(dataType);
