@@ -22,9 +22,10 @@ import org.guvnor.common.services.backend.util.CommentedOptionFactory;
 import org.junit.Before;
 import org.kie.workbench.common.forms.commons.shared.layout.FormLayoutTemplateGenerator;
 import org.kie.workbench.common.forms.commons.shared.layout.impl.StaticFormLayoutTemplateGenerator;
-import org.kie.workbench.common.forms.data.modeller.service.DataObjectFinderService;
+import org.kie.workbench.common.forms.data.modeller.service.ext.ModelReader;
+import org.kie.workbench.common.forms.data.modeller.service.shared.ModelFinderService;
 import org.kie.workbench.common.forms.editor.service.backend.FormModelHandlerManager;
-import org.kie.workbench.common.forms.editor.service.shared.VFSFormFinderService;
+import org.kie.workbench.common.forms.editor.service.shared.ModuleFormFinderService;
 import org.kie.workbench.common.forms.editor.service.shared.model.impl.FormModelSynchronizationUtilImpl;
 import org.kie.workbench.common.forms.fields.test.TestFieldManager;
 import org.kie.workbench.common.forms.fields.test.TestMetaDataEntryManager;
@@ -39,12 +40,12 @@ import org.kie.workbench.common.services.backend.project.ModuleClassLoaderHelper
 import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.base.options.CommentedOption;
 import org.uberfire.java.nio.fs.file.SimpleFileSystemProvider;
 
-import static org.mockito.Matchers.anyString;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
@@ -52,7 +53,7 @@ import static org.mockito.Mockito.when;
 public abstract class BPMNVFSFormDefinitionGeneratorServiceTest extends AbstractBPMNFormGeneratorServiceTest<BPMNVFSFormDefinitionGeneratorService, Path> {
 
     @Mock
-    protected VFSFormFinderService formFinderService;
+    protected ModuleFormFinderService formFinderService;
 
     @Mock
     protected IOService ioService;
@@ -61,12 +62,13 @@ public abstract class BPMNVFSFormDefinitionGeneratorServiceTest extends Abstract
     protected FormLayoutTemplateGenerator templateGenerator = new StaticFormLayoutTemplateGenerator();
 
     @Mock
-    protected DataObjectFinderService dataObjectFinderService;
+    protected ModelFinderService modelFinderService;
     protected FormModelHandlerManager formModelHandlerManager;
     protected FormDefinitionSerializer formSerializer = new FormDefinitionSerializerImpl(new FieldSerializer(),
                                                                                          new FormModelSerializer(),
                                                                                          new TestMetaDataEntryManager());
     protected SimpleFileSystemProvider simpleFileSystemProvider = null;
+
     @Mock
     protected CommentedOptionFactory commentedOptionFactory;
 
@@ -79,6 +81,9 @@ public abstract class BPMNVFSFormDefinitionGeneratorServiceTest extends Abstract
     @Mock
     private ModuleClassLoaderHelper projectClassLoaderHelper;
 
+    @Mock
+    protected ModelReader modelReader;
+
     @Before
     public void setup() throws IOException {
 
@@ -92,15 +97,15 @@ public abstract class BPMNVFSFormDefinitionGeneratorServiceTest extends Abstract
 
         when(source.toURI()).thenReturn("default:///src/main/resources/test.frm");
 
-        when(commentedOptionFactory.makeCommentedOption(anyString())).then(invocationOnMock -> new CommentedOption("1",
-                                                                                                                   invocationOnMock.getArguments()[0].toString()));
+        when(commentedOptionFactory.makeCommentedOption(Mockito.<String>any())).then(invocationOnMock -> new CommentedOption("1",
+                                                                                                                             invocationOnMock.getArguments()[0].toString()));
 
-        formModelHandlerManager = new TestFormModelHandlerManager(projectService,
-                                                                  projectClassLoaderHelper,
-                                                                  fieldManager,
-                                                                  dataObjectFinderService);
+        formModelHandlerManager = new TestFormModelHandlerManager(projectService, projectClassLoaderHelper, fieldManager, modelFinderService);
+
+        when(modelReaderService.getModelReader(any())).thenReturn(modelReader);
 
         service = new BPMNVFSFormDefinitionGeneratorService(fieldManager,
+                                                            modelReaderService,
                                                             formModelHandlerManager,
                                                             formFinderService,
                                                             formSerializer,
