@@ -18,6 +18,7 @@ package org.kie.workbench.common.screens.datamodeller.backend.server;
 
 import java.util.Arrays;
 import java.util.List;
+import java.util.Map;
 
 import javax.enterprise.inject.Instance;
 
@@ -35,8 +36,9 @@ import org.kie.workbench.common.services.datamodeller.core.impl.DataObjectImpl;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.mockito.Spy;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.ext.editor.commons.service.CopyService;
@@ -47,10 +49,8 @@ import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.java.nio.file.FileSystem;
 
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.anyMap;
-import static org.mockito.Mockito.anyString;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
@@ -138,45 +138,60 @@ public class DataModelerServiceTest {
     @Test
     public void saveSourcePackageNameChanged() {
         testSaveSource("newPackageName",
-                       null);
+                       null,
+                       new DataObjectImpl("dataobjects",
+                                          "TestDataObject"));
     }
 
     @Test
     public void saveSourceFileNameChanged() {
         testSaveSource(null,
-                       "newFileName");
+                       "newFileName",
+                       new DataObjectImpl("dataobjects",
+                                          "TestDataObject"));
     }
 
     @Test
     public void saveSourceBothPackageAndFileNameChanged() {
         testSaveSource("newPackageName",
-                       "newFileName");
+                       "newFileName",
+                       new DataObjectImpl("dataobjects",
+                                          "TestDataObject"));
+    }
+    
+    @Test
+    public void saveSourceBothPackageAndFileNameChangedNullDataObj() {
+        testSaveSource("newPackageName",
+                       "newFileName",
+                       null);
     }
 
     @Test
     public void saveSourceNoPackageAndFileNameChange() {
         testSaveSource(null,
-                       null);
+                       null,
+                       new DataObjectImpl("dataobjects",
+                                          "TestDataObject"));
     }
 
     private void testSaveSource(String newPackageName,
-                                String newFileName) {
+                                String newFileName,
+                                DataObject dataObject) {
         Path dataObjectPath = PathFactory.newPath("TestDataObject",
                                                   "file:///dataobjects/TestDataObject.java");
         Path srcPath = PathFactory.newPath("src",
                                            "file:///src");
         Package packageMock = mock(Package.class);
         when(packageMock.getPackageMainSrcPath()).thenReturn(srcPath);
-        when(serviceHelper.ensurePackageStructure(any(Module.class),
-                                                  anyString())).thenReturn(packageMock);
+        when(moduleService.resolvePackage(dataObjectPath)).thenReturn(packageMock);
+        when(packageMock.getPackageName()).thenReturn("dataobjects");
+        when(serviceHelper.ensurePackageStructure(Mockito.<Module>any(),
+                                                  Mockito.<String>any())).thenReturn(packageMock);
 
         DataModelerSaveHelper saveHelper = mock(DataModelerSaveHelper.class);
         List<DataModelerSaveHelper> saveHelpers = Arrays.asList(saveHelper);
         when(saveHelperInstance.iterator()).thenReturn(saveHelpers.iterator());
 
-        DataObject dataObject = new DataObjectImpl("dataobjects",
-                                                   "TestDataObject");
-
         dataModelerService.saveSource("Source",
                                       dataObjectPath,
                                       dataObject,
@@ -186,70 +201,108 @@ public class DataModelerServiceTest {
                                       newFileName);
 
         verify(ioService,
-               times(1)).startBatch(any(FileSystem.class));
+               times(1)).startBatch(Mockito.<FileSystem>any());
 
         if (newPackageName == null && newFileName == null) {
             verify(ioService,
-                   times(1)).write(any(org.uberfire.java.nio.file.Path.class),
-                                   anyString(),
-                                   anyMap(),
-                                   any(CommentedOption.class));
+                   times(1)).write(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                   Mockito.<String>any(),
+                                   Mockito.<Map>any(),
+                                   Mockito.<CommentedOption>any());
         } else if (newPackageName != null && newFileName != null) {
             verify(ioService,
-                   times(1)).write(any(org.uberfire.java.nio.file.Path.class),
-                                   anyString(),
-                                   anyMap(),
-                                   any(CommentedOption.class));
+                   times(1)).write(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                   Mockito.<String>any(),
+                                   Mockito.<Map>any(),
+                                   Mockito.<CommentedOption>any());
             verify(ioService,
-                   times(1)).move(any(org.uberfire.java.nio.file.Path.class),
-                                  any(org.uberfire.java.nio.file.Path.class),
-                                  any(CommentedOption.class));
+                   times(1)).move(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                  Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                  Mockito.<CommentedOption>any());
         } else if (newPackageName != null) {
             verify(ioService,
-                   times(1)).write(any(org.uberfire.java.nio.file.Path.class),
-                                   anyString(),
-                                   anyMap(),
-                                   any(CommentedOption.class));
+                   times(1)).write(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                   Mockito.<String>any(),
+                                   Mockito.<Map>any(),
+                                   Mockito.<CommentedOption>any());
             verify(ioService,
-                   times(1)).move(any(org.uberfire.java.nio.file.Path.class),
-                                  any(org.uberfire.java.nio.file.Path.class),
-                                  any(CommentedOption.class));
+                   times(1)).move(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                  Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                  Mockito.<CommentedOption>any());
         } else {
             verify(renameService,
-                   times(1)).rename(any(Path.class),
-                                    anyString(),
-                                    anyString());
+                   times(1)).rename(Mockito.<Path>any(),
+                                    Mockito.<String>any(),
+                                    Mockito.<String>any());
         }
 
         verify(saveHelper,
-               times(1)).postProcess(any(Path.class),
-                                     any(Path.class));
+               times(1)).postProcess(Mockito.<Path>any(),
+                                     Mockito.<Path>any());
         verify(ioService,
                times(1)).endBatch();
     }
 
     @Test
-    public void renameWorkaround() {
+    public void testRenameWorkaround() {
         Path dataObjectPath = PathFactory.newPath("TestDataObject",
                                                   "file:///dataobjects/TestDataObject.java");
+        Path targetPath = PathFactory.newPath("TestNewDataObject",
+                                              "file:///dataobjects/TestNewDataObject.java");
         DataModelerRenameWorkaroundHelper renameHelper = mock(DataModelerRenameWorkaroundHelper.class);
         List<DataModelerRenameWorkaroundHelper> renameHelpers = Arrays.asList(renameHelper);
         when(renameHelperInstance.iterator()).thenReturn(renameHelpers.iterator());
 
         dataModelerService.renameWorkaround(dataObjectPath,
-                                            "NewName",
+                                            targetPath,
                                             "New content",
                                             "Comment");
 
         verify(ioService,
-               times(1)).startBatch(any(FileSystem.class));
+               times(1)).startBatch(Mockito.<FileSystem>any());
         verify(ioService,
-               times(1)).move(any(org.uberfire.java.nio.file.Path.class),
-                              any(org.uberfire.java.nio.file.Path.class),
-                              any(CommentedOption.class));
+               times(1)).move(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                              Mockito.<org.uberfire.java.nio.file.Path>any(),
+                              Mockito.<CommentedOption>any());
+        verify(ioService,
+               times(1)).write(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                               eq("New content"),
+                               Mockito.<CommentedOption>any());
         verify(renameHelper,
-               times(1)).postProcess(any(Path.class),
-                                     any(Path.class));
+               times(1)).postProcess(Mockito.<Path>any(),
+                                     Mockito.<Path>any());
+        verify(ioService,
+               times(1)).endBatch();
+    }
+
+    @Test
+    public void testRenameWorkaroundWithoutNewContent() {
+        Path dataObjectPath = PathFactory.newPath("TestDataObject",
+                                                  "file:///dataobjects/TestDataObject.java");
+        Path targetPath = PathFactory.newPath("TestNewDataObject",
+                                              "file:///newdataobjects/TestNewDataObject.java");
+        DataModelerRenameWorkaroundHelper renameHelper = mock(DataModelerRenameWorkaroundHelper.class);
+        List<DataModelerRenameWorkaroundHelper> renameHelpers = Arrays.asList(renameHelper);
+        when(renameHelperInstance.iterator()).thenReturn(renameHelpers.iterator());
+
+        dataModelerService.renameWorkaround(dataObjectPath,
+                                            targetPath,
+                                            null,
+                                            "Comment");
+
+        verify(ioService,
+               times(1)).startBatch(Mockito.<FileSystem>any());
+        verify(ioService,
+               times(1)).move(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                              Mockito.<org.uberfire.java.nio.file.Path>any(),
+                              Mockito.<CommentedOption>any());
+        verify(ioService,
+               times(0)).write(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                               any(String.class),
+                               Mockito.<CommentedOption>any());
+        verify(renameHelper,
+               times(1)).postProcess(Mockito.<Path>any(),
+                                     Mockito.<Path>any());
         verify(ioService,
                times(1)).endBatch();
     }
@@ -258,7 +311,7 @@ public class DataModelerServiceTest {
     public void testCreateDataObjectAlreadyExists() {
         final Path path = PathFactory.newPath("DataObject.java", "file:///DataObject.java");
 
-        when(ioService.exists(any(org.uberfire.java.nio.file.Path.class))).thenReturn(true);
+        when(ioService.exists(Mockito.<org.uberfire.java.nio.file.Path>any())).thenReturn(true);
         assertThatThrownBy(() -> dataModelerService.createJavaFile(path, "", ""))
                 .isInstanceOf(FileAlreadyExistsException.class);
     }
