@@ -82,7 +82,7 @@ import org.uberfire.java.nio.file.Path;
 import org.uberfire.java.nio.file.api.FileSystemUtils;
 import org.uberfire.workbench.type.AnyResourceTypeDefinition;
 
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
