@@ -99,12 +99,13 @@ import org.kie.workbench.common.services.datamodel.backend.server.cache.LRUModul
 import org.kie.workbench.common.services.datamodel.backend.server.cache.ModuleDataModelOracleBuilderProvider;
 import org.kie.workbench.common.services.datamodel.backend.server.service.DataModelService;
 import org.kie.workbench.common.services.datamodel.spi.DataModelExtension;
+import org.kie.workbench.common.services.refactoring.service.PackageServiceLoader;
 import org.kie.workbench.common.services.shared.dependencies.DependencyService;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.services.shared.project.ProjectImportsService;
 import org.kie.workbench.common.services.shared.whitelist.PackageNameWhiteListService;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.backend.server.io.ConfigIOServiceProducer;
 import org.uberfire.backend.server.util.Paths;
 import org.uberfire.backend.vfs.Path;
@@ -128,7 +129,7 @@ import static org.kie.workbench.common.services.datamodel.backend.server.ModuleD
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class DataModelServiceConstructorTest {
 
     private SimpleFileSystemProvider fs = new SimpleFileSystemProvider();
@@ -241,6 +242,7 @@ public class DataModelServiceConstructorTest {
                                                        sessionInfo,
                                                        commentedOptionFactory,
                                                        mock(ModuleFinder.class),
+                                                       mock(PackageServiceLoader.class),
                                                        resourceResolver,
                                                        repositoryResolver);
 
@@ -423,6 +425,7 @@ public class DataModelServiceConstructorTest {
                                           SessionInfo sessionInfo,
                                           CommentedOptionFactory commentedOptionFactory,
                                           ModuleFinder moduleFinder,
+                                          PackageServiceLoader packageServiceLoader,
                                           KieResourceResolver resourceResolver,
                                           ModuleRepositoryResolver repositoryResolver) {
             super(ioService,
@@ -435,6 +438,7 @@ public class DataModelServiceConstructorTest {
                   sessionInfo,
                   commentedOptionFactory,
                   moduleFinder,
+                  packageServiceLoader,
                   resourceResolver,
                   repositoryResolver
             );
