@@ -26,24 +26,26 @@ import org.kie.workbench.common.stunner.core.client.components.palette.AbstractP
 import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteDefinitionBuilders.CategoryBuilder;
 import org.kie.workbench.common.stunner.core.definition.adapter.AdapterManager;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
+import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionId;
 import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.i18n.StunnerTranslationService;
+import org.kie.workbench.common.stunner.core.profile.DomainProfileManager;
 import org.kie.workbench.common.stunner.core.registry.impl.DefinitionsCacheRegistry;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ExpandedPaletteDefinitionBuilderTest {
 
     private static final String DEF1_ID = "def1";
@@ -80,6 +82,9 @@ public class ExpandedPaletteDefinitionBuilderTest {
     @Mock
     private DefinitionUtils definitionUtils;
 
+    @Mock
+    private DomainProfileManager profileManager;
+
     @Mock
     private DefinitionManager definitionManager;
 
@@ -111,11 +116,12 @@ public class ExpandedPaletteDefinitionBuilderTest {
         when(definitionUtils.getDefinitionManager()).thenReturn(definitionManager);
         when(definitionManager.adapters()).thenReturn(adapterManager);
         when(adapterManager.forDefinition()).thenReturn(definitionAdapter1);
-        when(definitionAdapter1.getId(eq(definition1))).thenReturn(DEF1_ID);
+        when(definitionAdapter1.getId(eq(definition1))).thenReturn(DefinitionId.build(DEF1_ID));
         when(definitionAdapter1.getCategory(eq(definition1))).thenReturn(DEF1_CATEGORY);
         when(definitionAdapter1.getTitle(eq(definition1))).thenReturn(DEF1_TITLE);
         when(definitionAdapter1.getDescription(eq(definition1))).thenReturn(DEF1_DESC);
         tested = new ExpandedPaletteDefinitionBuilder(definitionUtils,
+                                                      profileManager,
                                                       definitionsRegistry,
                                                       translationService);
     }
