@@ -17,7 +17,6 @@
 package org.kie.workbench.common.stunner.core.client.components.toolbox.actions;
 
 import java.util.Optional;
-import java.util.function.Consumer;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.junit.Before;
@@ -26,18 +25,17 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommand;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.client.components.toolbox.Toolbox;
-import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.mockito.Mock;
+import org.uberfire.mvp.Command;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.anyString;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -47,15 +45,24 @@ public class CommonActionsToolboxFactoryTest {
 
     private static final String E_UUID = "e1";
 
+    @Mock
+    private CanvasCommandManager<AbstractCanvasHandler> commandManager;
+
     @Mock
     private CanvasCommandFactory<AbstractCanvasHandler> commandFactory;
 
     @Mock
-    private DeleteNodeAction deleteNodeAction;
+    private DeleteNodeToolboxAction deleteNodeAction;
+
+    @Mock
+    private Command deleteNodeActionDestroyer;
 
     @Mock
     private ActionsToolboxView view;
 
+    @Mock
+    private Command viewDestroyer;
+
     @Mock
     private AbstractCanvasHandler canvasHandler;
 
@@ -72,15 +79,18 @@ public class CommonActionsToolboxFactoryTest {
         when(element.getUUID()).thenReturn(E_UUID);
         when(element.asNode()).thenReturn(element);
         when(commandFactory.deleteNode(eq(element))).thenReturn(deleteNodeCommand);
-        this.tested = new CommonActionsToolboxFactory(commandFactory,
+        this.tested = new CommonActionsToolboxFactory(commandManager,
+                                                      commandFactory,
                                                       () -> deleteNodeAction,
-                                                      () -> view);
+                                                      deleteNodeActionDestroyer,
+                                                      () -> view,
+                                                      viewDestroyer);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testBuildToolbox() {
-        when(deleteNodeCommand.allow(eq(canvasHandler))).thenReturn(CanvasCommandResultBuilder.SUCCESS);
+        when(commandManager.allow(eq(canvasHandler), eq(deleteNodeCommand))).thenReturn(CanvasCommandResultBuilder.SUCCESS);
         final Optional<Toolbox<?>> _toolbox =
                 tested.build(canvasHandler,
                              element);
@@ -96,18 +106,21 @@ public class CommonActionsToolboxFactoryTest {
                      actionsToolbox.iterator().next());
         verify(view,
                times(1)).init(eq(actionsToolbox));
-        verify(view,
-               times(1)).addButton(any(Glyph.class),
-                                   anyString(),
-                                   any(Consumer.class));
     }
 
     @Test
     public void testBuildToolboxNotAllowed() {
-        when(deleteNodeCommand.allow(eq(canvasHandler))).thenReturn(CanvasCommandResultBuilder.FAILED);
+        when(commandManager.allow(eq(canvasHandler), eq(deleteNodeCommand))).thenReturn(CanvasCommandResultBuilder.failed());
         final Optional<Toolbox<?>> toolbox =
                 tested.build(canvasHandler,
                              element);
         assertFalse(toolbox.isPresent());
     }
+
+    @Test
+    public void testDestroy() {
+        tested.destroy();
+        verify(deleteNodeActionDestroyer, times(1)).execute();
+        verify(viewDestroyer, times(1)).execute();
+    }
 }
