@@ -19,11 +19,15 @@ package org.kie.workbench.common.stunner.core.client.session.command.impl;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.appformer.client.stateControl.registry.Registry;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CurrentRegistryChangedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.registration.RegisterChangedEvent;
+import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent;
 import org.kie.workbench.common.stunner.core.client.session.command.AbstractClientSessionCommand;
@@ -31,12 +35,12 @@ import org.kie.workbench.common.stunner.core.client.session.command.ClientSessio
 import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
-import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
@@ -44,7 +48,7 @@ import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class UndoSessionCommandTest extends BaseSessionCommandKeyboardTest {
 
     @Mock
@@ -54,11 +58,14 @@ public class UndoSessionCommandTest extends BaseSessionCommandKeyboardTest {
     private ClientSessionCommand.Callback callback;
 
     @Mock
-    private CommandRegistry<Command<AbstractCanvasHandler, CanvasViolation>> commandRegistry;
+    private Registry<Command<AbstractCanvasHandler, CanvasViolation>> commandRegistry;
 
     @Mock
     private CommandResult commandResult;
 
+    @Mock
+    private SessionManager sessionManager;
+
     @Mock
     private org.uberfire.mvp.Command statusCallback;
 
@@ -68,10 +75,12 @@ public class UndoSessionCommandTest extends BaseSessionCommandKeyboardTest {
     @SuppressWarnings("unchecked")
     public void setup() {
         super.setup();
-        when(sessionCommandManager.getRegistry()).thenReturn(commandRegistry);
+        when(session.getCommandRegistry()).thenReturn(commandRegistry);
         commandHistory = new ArrayList<>();
-        when(commandRegistry.getCommandHistory()).thenReturn(commandHistory);
+        when(commandRegistry.getHistory()).thenReturn(commandHistory);
         when(session.getCanvasHandler()).thenReturn(canvasHandler);
+        when(session.getCommandRegistry()).thenReturn(commandRegistry);
+        when(sessionManager.getCurrentSession()).thenReturn(session);
     }
 
     @Override
@@ -92,13 +101,14 @@ public class UndoSessionCommandTest extends BaseSessionCommandKeyboardTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testExecuteSuccess() {
+        when(commandRegistry.isEmpty()).thenReturn(false);
         command.bind(session);
-        when(sessionCommandManager.undo(canvasHandler)).thenReturn(null);
+        when(sessionCommandManager.undo(eq(canvasHandler))).thenReturn(CanvasCommandResultBuilder.SUCCESS);
 
         command.execute(callback);
 
         verify(sessionCommandManager,
-               times(1)).undo(canvasHandler);
+               times(1)).undo(eq(canvasHandler));
         verify(selectionControl,
                times(1)).clearSelection();
         verify(callback,
@@ -110,14 +120,15 @@ public class UndoSessionCommandTest extends BaseSessionCommandKeyboardTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testExecuteWithErrors() {
+        when(commandRegistry.isEmpty()).thenReturn(false);
         command.bind(session);
-        when(sessionCommandManager.undo(canvasHandler)).thenReturn(commandResult);
+        when(sessionCommandManager.undo(eq(canvasHandler))).thenReturn(commandResult);
         when(commandResult.getType()).thenReturn(CommandResult.Type.ERROR);
 
         command.execute(callback);
 
         verify(sessionCommandManager,
-               times(1)).undo(canvasHandler);
+               times(1)).undo(eq(canvasHandler));
         verify(selectionControl,
                times(1)).clearSelection();
         verify(callback,
@@ -132,16 +143,37 @@ public class UndoSessionCommandTest extends BaseSessionCommandKeyboardTest {
         command.bind(session);
         command.listen(statusCallback);
 
-        ((UndoSessionCommand) command).onCommandAdded(new RegisterChangedEvent());
+        ((UndoSessionCommand) command).onCommandAdded(new RegisterChangedEvent(canvasHandler));
         assertFalse(command.isEnabled());
 
         commandHistory.add(mock(Command.class));
 
-        ((UndoSessionCommand) command).onCommandAdded(new RegisterChangedEvent());
+        ((UndoSessionCommand) command).onCommandAdded(new RegisterChangedEvent(canvasHandler));
         assertTrue(command.isEnabled());
         verify(statusCallback,
                atLeastOnce()).execute();
         verify(commandRegistry,
                never()).clear();
     }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testOnCommandExecutedCheckWrongSession() {
+        command.bind(session);
+        command.listen(statusCallback);
+
+        assertFalse(command.isEnabled());
+        verify(statusCallback,
+               never()).execute();
+        verify(commandRegistry,
+               never()).clear();
+    }
+
+    @Test
+    public void testOnCurrentRegistryChanged() {
+        final CurrentRegistryChangedEvent event = mock(CurrentRegistryChangedEvent.class);
+        ((UndoSessionCommand)command).onCurrentRegistryChanged(event);
+
+        verify((UndoSessionCommand)command).checkState();
+    }
 }
