@@ -16,7 +16,9 @@
 
 package org.kie.workbench.common.stunner.core.validation.impl;
 
+import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Objects;
@@ -24,7 +26,10 @@ import java.util.Optional;
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;
 import java.util.function.Supplier;
+import java.util.stream.Collectors;
+import java.util.stream.StreamSupport;
 
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Element;
@@ -34,6 +39,8 @@ import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.kie.workbench.common.stunner.core.validation.DiagramElementViolation;
 import org.kie.workbench.common.stunner.core.validation.DiagramValidator;
+import org.kie.workbench.common.stunner.core.validation.DomainValidator;
+import org.kie.workbench.common.stunner.core.validation.DomainViolation;
 import org.kie.workbench.common.stunner.core.validation.ModelValidator;
 
 /**
@@ -46,14 +53,38 @@ public abstract class AbstractDiagramValidator
     private final GraphValidatorImpl graphValidator;
     private final ModelValidator modelValidator;
 
+    private final ManagedInstance<DomainValidator> validators;
+
     protected AbstractDiagramValidator(final DefinitionManager definitionManager,
                                        final RuleManager ruleManager,
                                        final TreeWalkTraverseProcessor treeWalkTraverseProcessor,
-                                       final ModelValidator modelValidator) {
+                                       final ModelValidator modelValidator,
+                                       final ManagedInstance<DomainValidator> validators) {
+
         this.graphValidator = new GraphValidatorImpl(definitionManager,
                                                      ruleManager,
                                                      treeWalkTraverseProcessor);
         this.modelValidator = modelValidator;
+        this.validators = validators;
+    }
+
+    private Collection<DiagramElementViolation<RuleViolation>> validateDomain(Diagram diagram) {
+        return domainViolations(diagram).stream()
+                .filter(v -> Objects.nonNull(v.getUUID()))
+                .filter(v -> !"null".equals(v.getUUID()))
+                .map(v -> new ElementViolationImpl.Builder().setUuid(v.getUUID()).setDomainViolations(Collections.singletonList(v)).build())
+                .collect(Collectors.toList());
+    }
+
+    private Collection<DomainViolation> domainViolations(Diagram diagram) {
+        return StreamSupport.stream(validators.spliterator(), false)
+                .filter(validator -> Objects.equals(validator.getDefinitionSetId(), diagram.getMetadata().getDefinitionSetId()))
+                .findFirst()
+                .map(validator -> {
+                    final List<DomainViolation> domainViolations = new ArrayList<>();
+                    validator.validate(diagram, domainViolations::addAll);
+                    return domainViolations;
+                }).orElseGet(Collections::emptyList);
     }
 
     @Override
@@ -62,6 +93,10 @@ public abstract class AbstractDiagramValidator
                          final Consumer<Collection<DiagramElementViolation<RuleViolation>>> resultConsumer) {
         final Graph graph = diagram.getGraph();
         final List<DiagramElementViolation<RuleViolation>> violations = new LinkedList<>();
+
+        final Collection<DiagramElementViolation<RuleViolation>> diagramElementViolations = validateDomain(diagram);
+        violations.addAll(diagramElementViolations);
+
         graphValidator.validate(graph,
                                 Optional.empty(),
                                 Optional.of((g, v) -> consumeBeanAndViolations(() -> violations).accept(g, v)),
@@ -79,6 +114,7 @@ public abstract class AbstractDiagramValidator
                 // If the underlying bean is a Definition, it accomplishes JSR303 validations.
                 modelValidator.validate(element,
                                         modelViolations -> {
+
                                             if ((Objects.nonNull(ruleViolations) && !ruleViolations.isEmpty()) || (Objects.nonNull(modelViolations) && !modelViolations.isEmpty())) {
                                                 //Don't add a ElementViolation if there are no rule or model violations
                                                 violations.get().add(new ElementViolationImpl.Builder()
