@@ -35,17 +35,17 @@ import org.kie.workbench.common.stunner.core.rule.violations.CardinalityMaxRuleV
 import org.kie.workbench.common.stunner.core.rule.violations.DefaultRuleViolations;
 import org.kie.workbench.common.stunner.core.validation.Violation;
 import org.mockito.ArgumentCaptor;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.kie.workbench.common.stunner.core.TestingGraphUtils.verifyCardinality;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class DeleteNodeCommandTest extends AbstractGraphCommandTest {
 
     private static final String UUID = "nodeUUID";
@@ -57,7 +57,7 @@ public class DeleteNodeCommandTest extends AbstractGraphCommandTest {
     public void setup() throws Exception {
         super.init();
         node = mockNode(UUID);
-        graphNodes.add(node);
+        graph.addNode(node);
         when(graph.getNode(eq(UUID))).thenReturn(node);
         when(graphIndex.getNode(eq(UUID))).thenReturn(node);
         this.tested = new DeleteNodeCommand(UUID);
@@ -112,7 +112,7 @@ public class DeleteNodeCommandTest extends AbstractGraphCommandTest {
     @Test(expected = BadCommandArgumentsException.class)
     @SuppressWarnings("unchecked")
     public void testNodeNotPresentOnStorage() {
-        graphNodes.clear();
+        graph.clear();
         when(graphIndex.getNode(eq(UUID))).thenReturn(null);
         CommandResult<RuleViolation> result = tested.allow(graphCommandExecutionContext);
         assertEquals(CommandResult.Type.ERROR,
@@ -178,7 +178,7 @@ public class DeleteNodeCommandTest extends AbstractGraphCommandTest {
         assertEquals(CommandResult.Type.INFO,
                      result.getType());
         verify(graph,
-               times(1)).addNode(any(Node.class));
+               times(2)).addNode(any(Node.class));
         verify(graphIndex,
                times(1)).addNode(any(Node.class));
         verify(graph,
