@@ -39,16 +39,15 @@ import org.kie.workbench.common.stunner.core.graph.impl.GraphImpl;
 import org.kie.workbench.common.stunner.core.graph.impl.NodeImpl;
 import org.kie.workbench.common.stunner.core.graph.store.GraphNodeStoreImpl;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.stunner.core.graph.util.GraphUtils.computeCardinalityState;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class GraphUtilsTest {
 
     @Mock
@@ -156,37 +155,6 @@ public class GraphUtilsTest {
         assertEquals(dockedNodes.get(3), graphInstance.dockedNode);
     }
 
-    @Test
-    @SuppressWarnings("unchecked")
-    public void testGetPropertyForNullElement() {
-        assertNull(GraphUtils.getProperty(getDefinitionManager(),
-                                          (Element) null,
-                                          TestingSimpleDomainObject.NAME));
-    }
-
-    @Test
-    public void testGetPropertyForNonNullElement() {
-        assertEquals(domainObject.getPropertySet(), GraphUtils.getProperty(getDefinitionManager(),
-                                                                           element,
-                                                                           TestingSimpleDomainObject.PROPERTY_SET));
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void testGetPropertyForElementUsingField() {
-        assertEquals(domainObject.getNameProperty(), GraphUtils.getProperty(getDefinitionManager(),
-                                                                            element,
-                                                                            TestingSimpleDomainObject.NAME_FIELD));
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void testEmptyGetPropertyForElementUsingField() {
-        assertNull(GraphUtils.getProperty(getDefinitionManager(),
-                                          element,
-                                          TestingSimpleDomainObject.PROPERTY_SET + "." + "someField"));
-    }
-
     @Test
     @SuppressWarnings("unchecked")
     public void testGetChildIndex() {
