@@ -39,6 +39,7 @@ import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.client.widgets.presenters.Viewer;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
@@ -85,6 +86,7 @@ import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.mockito.Spy;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
@@ -98,6 +100,7 @@ import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
+import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
 import org.uberfire.ext.widgets.common.client.ace.AceEditorMode;
 import org.uberfire.ext.widgets.core.client.editors.texteditor.TextEditorView;
@@ -113,9 +116,8 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyBoolean;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doNothing;
@@ -251,6 +253,9 @@ public class AbstractProjectDiagramEditorTest {
     @Mock
     protected AbstractProjectDiagramEditorCore<ProjectMetadata, ProjectDiagram, ProjectDiagramResource, ProjectDiagramEditorProxy<ProjectDiagramResource>> presenterCore;
 
+    @Mock
+    protected SaveAndRenameCommandBuilder saveAndRenameCommandBuilderMock;
+
     protected boolean isReadOnly = false;
 
     protected Promises promises = new SyncPromises();
@@ -267,9 +272,9 @@ public class AbstractProjectDiagramEditorTest {
         sessionEditorPresenters = new ManagedInstanceStub<>(sessionEditorPresenter);
         sessionViewerPresenters = new ManagedInstanceStub<>(sessionViewerPresenter);
         when(sessionEditorPresenter.getInstance()).thenReturn(editorSession);
-        when(sessionEditorPresenter.withToolbar(anyBoolean())).thenReturn(sessionEditorPresenter);
-        when(sessionEditorPresenter.withPalette(anyBoolean())).thenReturn(sessionEditorPresenter);
-        when(sessionEditorPresenter.displayNotifications(any(Predicate.class))).thenReturn(sessionEditorPresenter);
+        when(sessionEditorPresenter.withToolbar(Mockito.anyBoolean())).thenReturn(sessionEditorPresenter);
+        when(sessionEditorPresenter.withPalette(Mockito.anyBoolean())).thenReturn(sessionEditorPresenter);
+        when(sessionEditorPresenter.displayNotifications(Mockito.<Predicate>any())).thenReturn(sessionEditorPresenter);
         when(sessionEditorPresenter.getView()).thenReturn(sessionPresenterView);
         when(sessionEditorPresenter.getSession()).thenReturn(Optional.of(editorSession));
         when(editorSession.getCanvasHandler()).thenReturn(canvasHandler);
@@ -281,12 +286,12 @@ public class AbstractProjectDiagramEditorTest {
             callback.afterSessionOpened();
             callback.onSuccess();
             return null;
-        }).when(sessionEditorPresenter).open(any(Diagram.class),
-                                             any(SessionPresenter.SessionPresenterCallback.class));
+        }).when(sessionEditorPresenter).open(Mockito.<Diagram>any(),
+                                             Mockito.<SessionPresenter.SessionPresenterCallback>any());
         when(sessionViewerPresenter.getInstance()).thenReturn(viewerSession);
-        when(sessionViewerPresenter.withToolbar(anyBoolean())).thenReturn(sessionViewerPresenter);
-        when(sessionViewerPresenter.withPalette(anyBoolean())).thenReturn(sessionViewerPresenter);
-        when(sessionViewerPresenter.displayNotifications(any(Predicate.class))).thenReturn(sessionViewerPresenter);
+        when(sessionViewerPresenter.withToolbar(Mockito.anyBoolean())).thenReturn(sessionViewerPresenter);
+        when(sessionViewerPresenter.withPalette(Mockito.anyBoolean())).thenReturn(sessionViewerPresenter);
+        when(sessionViewerPresenter.displayNotifications(Mockito.<Predicate>any())).thenReturn(sessionViewerPresenter);
         when(sessionViewerPresenter.getView()).thenReturn(sessionPresenterView);
         when(sessionViewerPresenter.getSession()).thenReturn(Optional.of(viewerSession));
         when(viewerSession.getCanvasHandler()).thenReturn(canvasHandler);
@@ -299,12 +304,12 @@ public class AbstractProjectDiagramEditorTest {
             callback.afterSessionOpened();
             callback.onSuccess();
             return null;
-        }).when(sessionViewerPresenter).open(any(Diagram.class),
-                                             any(SessionPresenter.SessionPresenterCallback.class));
+        }).when(sessionViewerPresenter).open(Mockito.<Diagram>any(),
+                                             Mockito.<SessionPresenter.SessionPresenterCallback>any());
         when(versionRecordManager.getPathToLatest()).thenReturn(filePath);
-        when(getMenuSessionItems().setErrorConsumer(any(Consumer.class))).thenReturn(getMenuSessionItems());
-        when(getMenuSessionItems().setLoadingCompleted(any(Command.class))).thenReturn(getMenuSessionItems());
-        when(getMenuSessionItems().setLoadingStarts(any(Command.class))).thenReturn(getMenuSessionItems());
+        when(getMenuSessionItems().setErrorConsumer(Mockito.<Consumer>any())).thenReturn(getMenuSessionItems());
+        when(getMenuSessionItems().setLoadingCompleted(Mockito.<Command>any())).thenReturn(getMenuSessionItems());
+        when(getMenuSessionItems().setLoadingStarts(Mockito.<Command>any())).thenReturn(getMenuSessionItems());
 
         resourceType = mockResourceType();
         presenter = createDiagramEditor();
@@ -380,6 +385,7 @@ public class AbstractProjectDiagramEditorTest {
                                                    errorPopupPresenter,
                                                    diagramClientErrorHandler,
                                                    translationService));
+                this.saveAndRenameCommandBuilder = saveAndRenameCommandBuilderMock;
                 return presenterCore;
             }
 
@@ -408,12 +414,12 @@ public class AbstractProjectDiagramEditorTest {
         presenter.makeMenuBar();
 
         verify(getMenuSessionItems()).populateMenu(eq(fileMenuBuilder));
-        verify(fileMenuBuilder).addSave(any(MenuItem.class));
-        verify(fileMenuBuilder).addCopy(any(Path.class),
-                                        any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addSave(Mockito.<MenuItem>any());
+        verify(fileMenuBuilder).addCopy(Mockito.<Path>any(),
+                                        Mockito.<AssetUpdateValidator>any());
         verify(fileMenuBuilder).addRename(saveAndRenameCommand);
-        verify(fileMenuBuilder).addDelete(any(Path.class),
-                                          any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addDelete(Mockito.<Path>any(),
+                                          Mockito.<AssetUpdateValidator>any());
         verify(presenter).addDownloadMenuItem(fileMenuBuilder);
     }
 
@@ -427,16 +433,16 @@ public class AbstractProjectDiagramEditorTest {
 
         verify(getMenuSessionItems()).populateMenu(eq(fileMenuBuilder));
         verify(fileMenuBuilder,
-               never()).addSave(any(MenuItem.class));
+               never()).addSave(Mockito.<MenuItem>any());
         verify(fileMenuBuilder,
-               never()).addCopy(any(Path.class),
-                                any(AssetUpdateValidator.class));
+               never()).addCopy(Mockito.<Path>any(),
+                                Mockito.<AssetUpdateValidator>any());
         verify(fileMenuBuilder,
-               never()).addRename(any(Path.class),
-                                  any(AssetUpdateValidator.class));
+               never()).addRename(Mockito.<Path>any(),
+                                  Mockito.<AssetUpdateValidator>any());
         verify(fileMenuBuilder,
-               never()).addDelete(any(Path.class),
-                                  any(AssetUpdateValidator.class));
+               never()).addDelete(Mockito.<Path>any(),
+                                  Mockito.<AssetUpdateValidator>any());
     }
 
     @Test
@@ -458,7 +464,7 @@ public class AbstractProjectDiagramEditorTest {
         verify(sessionEditorPresenter).withToolbar(eq(false));
         verify(sessionEditorPresenter).withPalette(eq(true));
         verify(sessionEditorPresenter).open(eq(diagram),
-                                            any(SessionPresenter.SessionPresenterCallback.class));
+                                            Mockito.<SessionPresenter.SessionPresenterCallback>any());
 
         assertEquals(diagram.hashCode(),
                      presenter.getCurrentDiagramHash());
@@ -470,7 +476,9 @@ public class AbstractProjectDiagramEditorTest {
         verify(kieView).clear();
         verify(kieView).addMainEditorPage(eq(view));
         verify(kieView).addOverviewPage(eq(overviewWidget),
-                                        any(com.google.gwt.user.client.Command.class));
+                                        Mockito.<com.google.gwt.user.client.Command>any());
+
+        verify(saveAndRenameCommandBuilderMock).addContentSupplier(any());
     }
 
     @Test
@@ -506,7 +514,7 @@ public class AbstractProjectDiagramEditorTest {
         verify(kieView).clear();
         verify(kieView).addMainEditorPage(eq(view));
         verify(kieView).addOverviewPage(eq(overviewWidget),
-                                        any(com.google.gwt.user.client.Command.class));
+                                        Mockito.<com.google.gwt.user.client.Command>any());
 
         assertEquals(sessionViewerPresenter,
                      presenterCore.getSessionPresenter());
@@ -514,13 +522,13 @@ public class AbstractProjectDiagramEditorTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testOpenWithInvalidBPMNFile() {
+    public void testLoadContentWithInvalidFile() {
         final String xml = "xml";
-        final Overview overview = openInvalidBPMNFile(xml);
+        final Overview overview = openInvalidFile(xml);
 
         assertEquals(VIEWER_SESSION_XML.hashCode(),
                      presenter.getCurrentDiagramHash());
-        verify(view).setWidget(any(IsWidget.class));
+        verify(view).setWidget(Mockito.<IsWidget>any());
         verify(view).hideBusyIndicator();
 
         //Verify Overview widget was setup. It'd be nice to just verify(presenter).resetEditorPages(..) but it is protected
@@ -529,7 +537,7 @@ public class AbstractProjectDiagramEditorTest {
         verify(kieView).clear();
         verify(kieView).addMainEditorPage(eq(view));
         verify(kieView).addOverviewPage(eq(overviewWidget),
-                                        any(com.google.gwt.user.client.Command.class));
+                                        Mockito.<com.google.gwt.user.client.Command>any());
 
         verify(getMenuSessionItems()).setEnabled(eq(false));
         verify(xmlEditorView).setReadOnly(eq(false));
@@ -538,7 +546,7 @@ public class AbstractProjectDiagramEditorTest {
     }
 
     @SuppressWarnings("unchecked")
-    protected Overview openInvalidBPMNFile(final String xml) {
+    protected Overview openInvalidFile(final String xml) {
         final ClientRuntimeError clientRuntimeError = mock(ClientRuntimeError.class);
         final DiagramParsingException dpe = mock(DiagramParsingException.class);
         final ProjectMetadata metadata = mock(ProjectMetadata.class);
@@ -555,8 +563,63 @@ public class AbstractProjectDiagramEditorTest {
             final ServiceCallback serviceCallback = (ServiceCallback) i.getArguments()[1];
             serviceCallback.onError(clientRuntimeError);
             return null;
-        }).when(clientProjectDiagramService).getByPath(any(Path.class),
-                                                       any(ServiceCallback.class));
+        }).when(clientProjectDiagramService).getByPath(Mockito.<Path>any(),
+                                                       Mockito.<ServiceCallback>any());
+
+        presenter.loadContent();
+
+        verify(presenterCore).destroySession();
+
+        return overview;
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testLoadContentWithValidFile() {
+        final String xml = "xml";
+        final Overview overview = openValidFile(xml);
+
+        verify(view).showLoading();
+        verify(view).setWidget(eq(sessionPresenterView));
+        verify(sessionEditorPresenter).withToolbar(eq(false));
+        verify(sessionEditorPresenter).withPalette(eq(true));
+        verify(sessionEditorPresenter).open(eq(diagram),
+                                            Mockito.<SessionPresenter.SessionPresenterCallback>any());
+
+        assertEquals(diagram.hashCode(),
+                     presenter.getCurrentDiagramHash());
+        verify(view).hideBusyIndicator();
+
+        //Verify Overview widget was setup. It'd be nice to just verify(presenter).resetEditorPages(..) but it is protected
+        verify(overviewWidget).setContent(eq(overview),
+                                          eq(filePath));
+        verify(kieView).clear();
+        verify(kieView).addMainEditorPage(eq(view));
+        verify(kieView).addOverviewPage(eq(overviewWidget),
+                                        Mockito.<com.google.gwt.user.client.Command>any());
+    }
+
+    @SuppressWarnings("unchecked")
+    protected Overview openValidFile(final String xml) {
+        final ClientRuntimeError clientRuntimeError = mock(ClientRuntimeError.class);
+        final DiagramParsingException dpe = mock(DiagramParsingException.class);
+        final ProjectMetadata metadata = mock(ProjectMetadata.class);
+        final Overview overview = mock(Overview.class);
+
+        when(metadata.getTitle()).thenReturn(TITLE);
+        when(metadata.getOverview()).thenReturn(overview);
+        when(clientRuntimeError.getThrowable()).thenReturn(dpe);
+        when(dpe.getMetadata()).thenReturn(metadata);
+        when(dpe.getXml()).thenReturn(xml);
+        when(diagram.getName()).thenReturn(TITLE);
+        when(diagram.getMetadata()).thenReturn(metadata);
+
+        doAnswer(i -> {
+            final ServiceCallback serviceCallback = (ServiceCallback) i.getArguments()[1];
+            serviceCallback.onSuccess(diagram);
+            return null;
+        }).when(clientProjectDiagramService).getByPath(Mockito.<Path>any(),
+                                                       Mockito.<ServiceCallback>any());
 
         presenter.loadContent();
 
@@ -569,13 +632,13 @@ public class AbstractProjectDiagramEditorTest {
         final ProjectMetadata metadata = mock(ProjectMetadata.class);
         final Overview overview = mock(Overview.class);
         when(diagram.getMetadata()).thenReturn(metadata);
-        when(metadata.getTitle()).thenReturn(TITLE);
+        when(diagram.getName()).thenReturn(TITLE);
         when(metadata.getOverview()).thenReturn(overview);
         final Graph graph = mock(Graph.class);
         final DefinitionSet definitionSet = mock(DefinitionSet.class);
         when(diagram.getGraph()).thenReturn(graph);
         when(graph.getContent()).thenReturn(definitionSet);
-        presenter.open(diagram);
+        presenter.open(diagram, mock(Viewer.Callback.class));
         return overview;
     }
 
@@ -639,7 +702,7 @@ public class AbstractProjectDiagramEditorTest {
                 callback.onError(Collections.singletonList(violation));
             }
             return null;
-        }).when(validateSessionCommand).execute(any(ClientSessionCommand.Callback.class));
+        }).when(validateSessionCommand).execute(Mockito.<ClientSessionCommand.Callback>any());
         presenter.save();
 
         return overview;
@@ -685,7 +748,7 @@ public class AbstractProjectDiagramEditorTest {
     @SuppressWarnings("unchecked")
     public void testStunnerSave_ValidationUnsuccessful() {
         assertBasicStunnerSaveOperation(false);
-        verify(presenterCore).onValidationFailed(any(Collection.class));
+        verify(presenterCore).onValidationFailed(Mockito.<Collection>any());
         verify(view, atLeastOnce()).hideBusyIndicator();
     }
 
@@ -785,7 +848,7 @@ public class AbstractProjectDiagramEditorTest {
     @SuppressWarnings("unchecked")
     private ServiceCallback<String> assertBasicXMLSaveOperation(final String xml) {
         final String commitMessage = "message";
-        final Overview overview = openInvalidBPMNFile(xml);
+        final Overview overview = openInvalidFile(xml);
         final Metadata metadata = overview.getMetadata();
         EditorSessionCommands editorSessionCommands = mock(EditorSessionCommands.class);
         when(getMenuSessionItems().getCommands()).thenReturn(editorSessionCommands);
@@ -795,7 +858,7 @@ public class AbstractProjectDiagramEditorTest {
             ClientSessionCommand.Callback callback = (ClientSessionCommand.Callback) invocation.getArguments()[0];
             callback.onSuccess();
             return null;
-        }).when(validateSessionCommand).execute(any(ClientSessionCommand.Callback.class));
+        }).when(validateSessionCommand).execute(Mockito.<ClientSessionCommand.Callback>any());
         doReturn(xml).when(xmlEditorView).getContent();
 
         presenter.save();
@@ -839,11 +902,11 @@ public class AbstractProjectDiagramEditorTest {
     }
 
     @Test
-    public void testDiagramHashCodeWithInvalidBPMNFile() {
+    public void testDiagramHashCodeWithInvalidFile() {
         final String xml = "xml";
         when(xmlEditorView.getContent()).thenReturn(xml);
 
-        openInvalidBPMNFile(xml);
+        openInvalidFile(xml);
 
         assertEquals(xml.hashCode(),
                      presenter.getCurrentDiagramHash());
