@@ -29,6 +29,7 @@ import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.client.widgets.presenters.Viewer;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
@@ -80,6 +81,7 @@ import org.uberfire.client.workbench.type.ClientResourceType;
 import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
+import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.widgets.core.client.editors.texteditor.TextEditorView;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
@@ -91,10 +93,10 @@ import org.uberfire.workbench.events.NotificationEvent;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.ArgumentCaptor.forClass;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyBoolean;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
@@ -235,6 +237,10 @@ public class ProjectDiagramEditorTest {
     @Mock
     private Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller;
 
+    @Mock
+    private SaveAndRenameCommandBuilder saveAndRenameCommandBuilderMock;
+
+
     private ProjectDiagramEditorStub presenter;
 
     private AbstractProjectDiagramEditorCore<ProjectMetadata, ProjectDiagram, ProjectDiagramResource, ProjectDiagramEditorProxy<ProjectDiagramResource>> presenterCore;
@@ -273,7 +279,7 @@ public class ProjectDiagramEditorTest {
         }).when(sessionEditorPresenter).open(any(Diagram.class),
                                              any(SessionPresenter.SessionPresenterCallback.class));
         when(diagram.getMetadata()).thenReturn(metadata);
-        when(metadata.getTitle()).thenReturn("Title");
+        when(diagram.getName()).thenReturn("Title");
         when(metadata.getOverview()).thenReturn(overview);
         when(overview.getMetadata()).thenReturn(kieMetadata);
         when(fullSession.getCanvasHandler()).thenReturn(canvasHandler);
@@ -336,6 +342,11 @@ public class ProjectDiagramEditorTest {
                                                    translationService));
                 return presenterCore;
             }
+
+            @Override
+            protected SaveAndRenameCommandBuilder<ProjectDiagramResource, Metadata> getSaveAndRenameCommandBuilder() {
+                return saveAndRenameCommandBuilderMock;
+            }
         };
         presenter.init();
         presenterCore.setEditorSessionPresenter(sessionEditorPresenter);
@@ -395,7 +406,7 @@ public class ProjectDiagramEditorTest {
     @Test
     public void testIsDirty() {
         presenter.init();
-        presenter.open(diagram);
+        presenter.open(diagram, mock(Viewer.Callback.class));
         assertFalse(presenter.isDirty(presenter.getCurrentDiagramHash()));
         presenter.setOriginalHash(~~(presenter.getCurrentDiagramHash() + 1));
         assertTrue(presenter.isDirty(presenter.getCurrentDiagramHash()));
@@ -404,7 +415,7 @@ public class ProjectDiagramEditorTest {
     @Test
     public void testHasChanges() {
         presenter.init();
-        presenter.open(diagram);
+        presenter.open(diagram, mock(Viewer.Callback.class));
         assertFalse(presenter.hasUnsavedChanges());
         presenter.setOriginalHash(~~(presenter.getCurrentDiagramHash() + 1));
         assertTrue(presenter.hasUnsavedChanges());
@@ -414,7 +425,7 @@ public class ProjectDiagramEditorTest {
 
     @Test
     public void testOnSaveWithoutChanges() {
-        presenter.open(diagram);
+        presenter.open(diagram, mock(Viewer.Callback.class));
         when(versionRecordManager.isCurrentLatest()).thenReturn(true);
 
         presenter.onSave();
@@ -425,7 +436,7 @@ public class ProjectDiagramEditorTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testOnSaveWithChanges() {
-        presenter.open(diagram);
+        presenter.open(diagram, mock(Viewer.Callback.class));
         presenter.setOriginalHash(diagram.hashCode() + 1);
         doAnswer(i -> {
             ((ClientSessionCommand.Callback) i.getArguments()[0]).onSuccess();
@@ -440,7 +451,7 @@ public class ProjectDiagramEditorTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testOnSaveRestore() {
-        presenter.open(diagram);
+        presenter.open(diagram, mock(Viewer.Callback.class));
         doAnswer(i -> {
             ((ClientSessionCommand.Callback) i.getArguments()[0]).onSuccess();
             return null;
