@@ -24,6 +24,7 @@ import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.client.lienzo.shape.impl.ShapeStateDefaultHandler;
 import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeDefFunctionalFactory;
 import org.kie.workbench.common.stunner.svg.client.shape.SVGShape;
 import org.kie.workbench.common.stunner.svg.client.shape.def.SVGShapeDef;
@@ -31,14 +32,13 @@ import org.kie.workbench.common.stunner.svg.client.shape.def.SVGShapeViewDef;
 import org.kie.workbench.common.stunner.svg.client.shape.impl.SVGMutableShapeImpl;
 import org.kie.workbench.common.stunner.svg.client.shape.impl.SVGShapeImpl;
 import org.kie.workbench.common.stunner.svg.client.shape.view.SVGShapeView;
-import org.kie.workbench.common.stunner.svg.client.shape.view.impl.SVGShapeStateHandler;
 import org.kie.workbench.common.stunner.svg.client.shape.view.impl.SVGShapeViewImpl;
 import org.mockito.Mock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.spy;
@@ -66,13 +66,13 @@ public class SVGShapeFactoryTest {
     private SVGShapeViewImpl shapeView;
 
     @Mock
-    private SVGShapeStateHandler shapeViewStateHandler;
+    private ShapeStateDefaultHandler shapeViewStateHandler;
 
     @Mock
     private SVGShapeViewImpl shapeViewImpl;
 
     @Mock
-    private SVGShapeStateHandler shapeViewImplStateHandler;
+    private ShapeStateDefaultHandler shapeViewImplStateHandler;
 
     @Mock
     private BiConsumer<Object, SVGShapeView> viewHandler;
