@@ -41,12 +41,10 @@ import org.kie.workbench.common.stunner.bpmn.forms.model.MultipleInstanceVariabl
 import org.kie.workbench.common.stunner.bpmn.forms.model.NotificationsEditorFieldType;
 import org.kie.workbench.common.stunner.bpmn.forms.model.ReassignmentsEditorFieldType;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @Portable
 @Bindable
-@PropertySet
 @FormDefinition(startElement = "taskName")
 public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
 
@@ -94,7 +92,6 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
     @Valid
     private ReassignmentsInfo reassignmentsInfo;
 
-
     @Property
     @FormField(
             type = NotificationsEditorFieldType.class,
@@ -149,7 +146,18 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
     private IsMultipleInstance isMultipleInstance;
 
     @Property
-    @FormField(type = ListBoxFieldType.class, afterElement = "isMultipleInstance")
+    @Valid
+    @FormField(afterElement = "isMultipleInstance",
+            type = ListBoxFieldType.class,
+            settings = {@FieldParam(name = "addEmptyOption", value = "false")}
+    )
+    @SelectorDataProvider(
+            type = SelectorDataProvider.ProviderType.CLIENT,
+            className = "org.kie.workbench.common.stunner.bpmn.client.dataproviders.ExecutionOrderProvider")
+    private MultipleInstanceExecutionMode multipleInstanceExecutionMode;
+
+    @Property
+    @FormField(type = ListBoxFieldType.class, afterElement = "multipleInstanceExecutionMode")
     @SelectorDataProvider(
             type = SelectorDataProvider.ProviderType.CLIENT,
             className = "org.kie.workbench.common.stunner.bpmn.client.dataproviders.VariablesProvider"
@@ -234,6 +242,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
              new CreatedBy(),
              new AdHocAutostart(),
              new IsMultipleInstance(false),
+             new MultipleInstanceExecutionMode(false),
              new MultipleInstanceCollectionInput(),
              new MultipleInstanceDataInput(),
              new MultipleInstanceCollectionOutput(),
@@ -261,6 +270,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
                                 final @MapsTo("createdBy") CreatedBy createdBy,
                                 final @MapsTo("adHocAutostart") AdHocAutostart adHocAutostart,
                                 final @MapsTo("isMultipleInstance") IsMultipleInstance isMultipleInstance,
+                                final @MapsTo("multipleInstanceExecutionMode") MultipleInstanceExecutionMode multipleInstanceExecutionMode,
                                 final @MapsTo("multipleInstanceCollectionInput") MultipleInstanceCollectionInput multipleInstanceCollectionInput,
                                 final @MapsTo("multipleInstanceDataInput") MultipleInstanceDataInput multipleInstanceDataInput,
                                 final @MapsTo("multipleInstanceCollectionOutput") MultipleInstanceCollectionOutput multipleInstanceCollectionOutput,
@@ -284,6 +294,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
         this.createdBy = createdBy;
         this.adHocAutostart = adHocAutostart;
         this.isMultipleInstance = isMultipleInstance;
+        this.multipleInstanceExecutionMode = multipleInstanceExecutionMode;
         this.multipleInstanceCollectionInput = multipleInstanceCollectionInput;
         this.multipleInstanceDataInput = multipleInstanceDataInput;
         this.multipleInstanceCollectionOutput = multipleInstanceCollectionOutput;
@@ -412,14 +423,25 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
         this.adHocAutostart = adHocAutostart;
     }
 
+    @Override
     public IsMultipleInstance getIsMultipleInstance() {
         return isMultipleInstance;
     }
 
+    @Override
+    public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
+        return multipleInstanceExecutionMode;
+    }
+
+    public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
+        this.multipleInstanceExecutionMode = multipleInstanceExecutionMode;
+    }
+
     public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
         this.isMultipleInstance = isMultipleInstance;
     }
 
+    @Override
     public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
         return multipleInstanceCollectionInput;
     }
@@ -428,6 +450,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
         this.multipleInstanceCollectionInput = multipleInstanceCollectionInput;
     }
 
+    @Override
     public MultipleInstanceDataInput getMultipleInstanceDataInput() {
         return multipleInstanceDataInput;
     }
@@ -436,6 +459,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
         this.multipleInstanceDataInput = multipleInstanceDataInput;
     }
 
+    @Override
     public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
         return multipleInstanceCollectionOutput;
     }
@@ -444,6 +468,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
         this.multipleInstanceCollectionOutput = multipleInstanceCollectionOutput;
     }
 
+    @Override
     public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
         return multipleInstanceDataOutput;
     }
@@ -452,6 +477,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
         this.multipleInstanceDataOutput = multipleInstanceDataOutput;
     }
 
+    @Override
     public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
         return multipleInstanceCompletionCondition;
     }
@@ -512,6 +538,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
                                          Objects.hashCode(createdBy),
                                          Objects.hashCode(adHocAutostart),
                                          Objects.hashCode(isMultipleInstance),
+                                         Objects.hashCode(multipleInstanceExecutionMode),
                                          Objects.hashCode(multipleInstanceCollectionInput),
                                          Objects.hashCode(multipleInstanceDataInput),
                                          Objects.hashCode(multipleInstanceCollectionOutput),
@@ -544,6 +571,7 @@ public class UserTaskExecutionSet implements BaseUserTaskExecutionSet {
                     Objects.equals(createdBy, other.createdBy) &&
                     Objects.equals(adHocAutostart, other.adHocAutostart) &&
                     Objects.equals(isMultipleInstance, other.isMultipleInstance) &&
+                    Objects.equals(multipleInstanceExecutionMode, other.multipleInstanceExecutionMode) &&
                     Objects.equals(multipleInstanceCollectionInput, other.multipleInstanceCollectionInput) &&
                     Objects.equals(multipleInstanceDataInput, other.multipleInstanceDataInput) &&
                     Objects.equals(multipleInstanceCollectionOutput, other.multipleInstanceCollectionOutput) &&
