@@ -17,7 +17,9 @@ package org.kie.workbench.common.stunner.kogito.client.editor;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Optional;
 import java.util.function.Consumer;
 
@@ -54,6 +56,7 @@ import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.kie.workbench.common.stunner.core.validation.DiagramElementViolation;
 import org.kie.workbench.common.stunner.core.validation.DomainViolation;
+import org.kie.workbench.common.stunner.core.validation.Violation;
 import org.kie.workbench.common.stunner.forms.client.event.FormPropertiesOpened;
 import org.kie.workbench.common.stunner.forms.client.widgets.FormsFlushManager;
 import org.kie.workbench.common.stunner.kogito.client.docks.DiagramEditorPreviewAndExplorerDock;
@@ -85,8 +88,11 @@ import org.uberfire.lifecycle.OnMayClose;
 import org.uberfire.lifecycle.OnOpen;
 import org.uberfire.lifecycle.OnStartup;
 import org.uberfire.lifecycle.SetContent;
+import org.uberfire.lifecycle.Validate;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
+import org.uberfire.workbench.model.bridge.Notification;
+import org.uberfire.workbench.model.bridge.NotificationSeverity;
 import org.uberfire.workbench.model.menu.Menus;
 
 @ApplicationScoped
@@ -104,10 +110,16 @@ public class BPMNDiagramEditor extends AbstractDiagramEditor {
     protected final FormsFlushManager formsFlushManager;
     private final CanvasFileExport canvasFileExport;
     private final Promises promises;
-    private final CanvasDiagramValidator<AbstractCanvasHandler> validator;
+    private CanvasDiagramValidator<AbstractCanvasHandler> validator;
 
     protected String formElementUUID;
 
+    private static final Map<Violation.Type, String> validationSeverityTable = new HashMap<Violation.Type, String>() {{
+        put(Violation.Type.INFO, NotificationSeverity.INFO);
+        put(Violation.Type.WARNING, NotificationSeverity.WARNING);
+        put(Violation.Type.ERROR, NotificationSeverity.ERROR);
+    }};
+
     @Inject
     public BPMNDiagramEditor(final View view,
                              final FileMenuBuilder fileMenuBuilder,
@@ -198,7 +210,6 @@ public class BPMNDiagramEditor extends AbstractDiagramEditor {
     @Override
     public void onDiagramLoad() {
         final Optional<CanvasHandler> canvasHandler = Optional.ofNullable(getCanvasHandler());
-
         canvasHandler.ifPresent(c -> {
             final Metadata metadata = c.getDiagram().getMetadata();
             metadata.setPath(makeMetadataPath(metadata.getRoot(), metadata.getTitle()));
@@ -274,28 +285,9 @@ public class BPMNDiagramEditor extends AbstractDiagramEditor {
     @Override
     public Promise getContent() {
         flush();
-        validateDiagram(getCanvasHandler());
         return diagramServices.transform(getEditor().getEditorProxy().getContentSupplier().get());
     }
 
-    private void validateDiagram(CanvasHandler canvasHandler) {
-        getSessionPresenter().displayNotifications(t -> false);
-
-        validator.validate((AbstractCanvasHandler) canvasHandler, violations -> {
-            String errorMessage = getTranslationService().getValue(StunnerWidgetsConstants.MarshallingResponsePopup_ErrorMessageLabel);
-
-            if (!violations.isEmpty()) {
-                List<String> violationMessages = new ArrayList<>();
-                for (DiagramElementViolation<RuleViolation> next : violations) {
-                    final Collection<DomainViolation> domainViolations = next.getDomainViolations();
-                    domainViolations.forEach(item -> violationMessages.add(errorMessage + ": " + item.getUUID() + " - " + item.getMessage() + " - " + item.getViolationType()));
-                }
-                getEditor().getSessionPresenter().getView().showWarning(errorMessage + "(s): " + violationMessages);
-            }
-        });
-        getSessionPresenter().displayNotifications(t -> true);
-    }
-
     @GetPreview
     public Promise getPreview() {
         CanvasHandler canvasHandler = getCanvasHandler();
@@ -306,6 +298,40 @@ public class BPMNDiagramEditor extends AbstractDiagramEditor {
         }
     }
 
+    @Validate
+    public Promise validate() {
+        CanvasHandler canvasHandler = getCanvasHandler();
+        getSessionPresenter().displayNotifications(t -> false);
+
+        List<Notification> violationMessages = new ArrayList<>();
+
+        validator.validate((AbstractCanvasHandler) canvasHandler, violations -> {
+
+            if (!violations.isEmpty()) {
+                for (DiagramElementViolation<RuleViolation> next : violations) {
+                    final Collection<DomainViolation> domainViolations = next.getDomainViolations();
+                    domainViolations.forEach(item -> violationMessages.add(createNotification(item)));
+                }
+            }
+        });
+
+        return Promise.resolve(violationMessages.toArray(new Notification[0]));
+    }
+
+    private Notification createNotification(DomainViolation item) {
+        CanvasHandler canvasHandler = getCanvasHandler();
+        String errorMessage = getTranslationService().getValue(StunnerWidgetsConstants.MarshallingResponsePopup_ErrorMessageLabel);
+        Notification notification = new Notification();
+        notification.setMessage(errorMessage + ": " + item.getUUID() + " - " + item.getMessage());
+        notification.setSeverity(translateViolationType(item.getViolationType()));
+        notification.setPath(canvasHandler.getDiagram().getMetadata().getPath().toString());
+        return notification;
+    }
+
+    private String translateViolationType(Violation.Type violationType) {
+        return this.validationSeverityTable.getOrDefault(violationType, NotificationSeverity.INFO);
+    }
+
     @Override
     @IsDirty
     public boolean isDirty() {
