@@ -60,7 +60,7 @@ import org.uberfire.promise.SyncPromises;
 import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.jgroups.util.Util.assertEquals;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.inOrder;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
@@ -176,7 +176,8 @@ public class BPMNDiagramEditorTest {
                                            diagramServices,
                                            formsFlushManager,
                                            canvasFileExport,
-                                           promises, validator));
+                                           promises,
+                                           validator));
 
         when(editor.getSessionPresenter()).thenReturn(sessionPresenter);
         when(sessionPresenter.getInstance()).thenReturn(clientSession);
