@@ -19,31 +19,42 @@ package org.kie.workbench.common.stunner.bpmn.client.marshall.converters.fromstu
 import java.util.HashSet;
 
 import bpsim.ElementParameters;
+import org.eclipse.bpmn2.ErrorEventDefinition;
 import org.eclipse.bpmn2.StartEvent;
+import org.junit.Before;
 import org.junit.Test;
+import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.kie.workbench.common.stunner.bpmn.client.marshall.converters.fromstunner.Factories.bpmn2;
+import static org.mockito.Mockito.spy;
 
-public class CatchEventPropertyWriterTest {
+@RunWith(MockitoJUnitRunner.class)
+public class CatchEventPropertyWriterTest extends EventPropertyWriterTest {
+
+    @Before
+    public void init() {
+        event = bpmn2.createStartEvent();
+        event.setId(elementId);
+        propertyWriter = spy(new CatchEventPropertyWriter((StartEvent) event,
+                                                          new FlatVariableScope(),
+                                                          new HashSet<>()));
+    }
 
     @Test
     public void simulationSetMustHaveElementRef() {
-        String elementId = "MY_ID";
-        StartEvent startEvent = bpmn2.createStartEvent();
-        startEvent.setId(elementId);
-
-        CatchEventPropertyWriter p =
-                new CatchEventPropertyWriter(
-                        startEvent,
-                        new FlatVariableScope(),
-                        new HashSet<>());
-
         SimulationAttributeSet defaults = new SimulationAttributeSet();
-        p.setSimulationSet(defaults);
+        CatchEventPropertyWriter catchEventPropertyWriter = (CatchEventPropertyWriter) propertyWriter;
+        catchEventPropertyWriter.setSimulationSet(defaults);
 
-        ElementParameters simulationParameters = p.getSimulationParameters();
+        ElementParameters simulationParameters = propertyWriter.getSimulationParameters();
         assertEquals(elementId, simulationParameters.getElementRef());
     }
+
+    @Override
+    public ErrorEventDefinition getErrorDefinition() {
+        return (ErrorEventDefinition) ((StartEvent) event).getEventDefinitions().get(0);
+    }
 }
\ No newline at end of file
