@@ -18,6 +18,7 @@ package org.kie.workbench.common.widgets.configresource.client.widget.bound;
 
 import java.util.ArrayList;
 import java.util.List;
+
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
 
@@ -38,7 +39,6 @@ import com.google.gwt.user.client.Command;
 import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.Widget;
 import com.google.gwt.view.client.ListDataProvider;
-import org.drools.workbench.models.datamodel.imports.Import;
 import org.gwtbootstrap3.client.ui.Button;
 import org.gwtbootstrap3.client.ui.Label;
 import org.gwtbootstrap3.client.ui.constants.ButtonSize;
@@ -46,7 +46,9 @@ import org.gwtbootstrap3.client.ui.constants.ButtonType;
 import org.gwtbootstrap3.client.ui.constants.IconType;
 import org.gwtbootstrap3.client.ui.gwt.ButtonCell;
 import org.gwtbootstrap3.client.ui.gwt.CellTable;
+import org.kie.soup.project.datamodel.imports.Import;
 import org.kie.workbench.common.widgets.configresource.client.resources.i18n.ImportConstants;
+import org.kie.workbench.common.widgets.configresource.client.widget.BuiltInTypeImportHelper;
 import org.kie.workbench.common.widgets.configresource.client.widget.Sorters;
 import org.uberfire.client.mvp.LockRequiredEvent;
 import org.uberfire.ext.widgets.common.client.common.popups.YesNoCancelPopup;
@@ -83,6 +85,69 @@ public class ImportsWidgetViewImpl
 
     private boolean isReadOnly = false;
 
+    final TextColumn<Import> importTypeColumn = new TextColumn<Import>() {
+
+        @Override
+        public String getValue(final Import importType) {
+            return importType.getType();
+        }
+    };
+
+    private ButtonCell deleteImportButton = new ButtonCell(IconType.TRASH,
+                                                           ButtonType.DANGER,
+                                                           ButtonSize.SMALL) {
+        @Override
+        public void render(final com.google.gwt.cell.client.Cell.Context context,
+                           final SafeHtml data,
+                           final SafeHtmlBuilder sb) {
+            //Don't render a "Delete" button for "internal" Fact Types
+            if (isExternalImport(context.getIndex()) &&
+                    !BuiltInTypeImportHelper.isBuiltIn(getDataProvider().getList().get(context.getIndex()))) {
+                super.render(context,
+                             data,
+                             sb);
+            }
+        }
+
+        @Override
+        public void onBrowserEvent(final Context context,
+                                   final Element parent,
+                                   final String value,
+                                   final NativeEvent event,
+                                   final ValueUpdater<String> valueUpdater) {
+            //Don't act on cell interactions for "internal" Fact Types
+            if (isExternalImport(context.getIndex())) {
+                super.onBrowserEvent(context,
+                                     parent,
+                                     value,
+                                     event,
+                                     valueUpdater);
+            }
+        }
+
+        @Override
+        protected void onEnterKeyDown(final Context context,
+                                      final Element parent,
+                                      final String value,
+                                      final NativeEvent event,
+                                      final ValueUpdater<String> valueUpdater) {
+            //Don't act on cell interactions for "internal" Fact Types
+            if (isExternalImport(context.getIndex())) {
+                super.onEnterKeyDown(context,
+                                     parent,
+                                     value,
+                                     event,
+                                     valueUpdater);
+            }
+        }
+    };
+    private Column<Import, String> deleteImportColumn = new Column<Import, String>(deleteImportButton) {
+        @Override
+        public String getValue(final Import importType) {
+            return ImportConstants.INSTANCE.remove();
+        }
+    };
+
     public ImportsWidgetViewImpl() {
         //CDI proxy
     }
@@ -108,67 +173,11 @@ public class ImportsWidgetViewImpl
         table.setEmptyTableWidget(new Label(ImportConstants.INSTANCE.noImportsDefined()));
 
         //Columns
-        final TextColumn<Import> importTypeColumn = new TextColumn<Import>() {
+        table.addColumn(importTypeColumn,
+                        new TextHeader(ImportConstants.INSTANCE.importType()));
+        table.addColumn(deleteImportColumn,
+                        ImportConstants.INSTANCE.remove());
 
-            @Override
-            public String getValue(final Import importType) {
-                return importType.getType();
-            }
-        };
-
-        final ButtonCell deleteImportButton = new ButtonCell(IconType.TRASH,
-                                                             ButtonType.DANGER,
-                                                             ButtonSize.SMALL) {
-            @Override
-            public void render(final com.google.gwt.cell.client.Cell.Context context,
-                               final SafeHtml data,
-                               final SafeHtmlBuilder sb) {
-                //Don't render a "Delete" button for "internal" Fact Types
-                if (isExternalImport(context.getIndex())) {
-                    super.render(context,
-                                 data,
-                                 sb);
-                }
-            }
-
-            @Override
-            public void onBrowserEvent(final Context context,
-                                       final Element parent,
-                                       final String value,
-                                       final NativeEvent event,
-                                       final ValueUpdater<String> valueUpdater) {
-                //Don't act on cell interactions for "internal" Fact Types
-                if (isExternalImport(context.getIndex())) {
-                    super.onBrowserEvent(context,
-                                         parent,
-                                         value,
-                                         event,
-                                         valueUpdater);
-                }
-            }
-
-            @Override
-            protected void onEnterKeyDown(final Context context,
-                                          final Element parent,
-                                          final String value,
-                                          final NativeEvent event,
-                                          final ValueUpdater<String> valueUpdater) {
-                //Don't act on cell interactions for "internal" Fact Types
-                if (isExternalImport(context.getIndex())) {
-                    super.onEnterKeyDown(context,
-                                         parent,
-                                         value,
-                                         event,
-                                         valueUpdater);
-                }
-            }
-        };
-        final Column<Import, String> deleteImportColumn = new Column<Import, String>(deleteImportButton) {
-            @Override
-            public String getValue(final Import importType) {
-                return ImportConstants.INSTANCE.remove();
-            }
-        };
         deleteImportColumn.setFieldUpdater((index,
                                             importType,
                                             value) -> {
@@ -183,11 +192,6 @@ public class ImportsWidgetViewImpl
             confirm.show();
         });
 
-        table.addColumn(importTypeColumn,
-                        new TextHeader(ImportConstants.INSTANCE.importType()));
-        table.addColumn(deleteImportColumn,
-                        ImportConstants.INSTANCE.remove());
-
         //Link display
         getDataProvider().addDataDisplay(table);
     }
@@ -257,4 +261,19 @@ public class ImportsWidgetViewImpl
     ListDataProvider<Import> getDataProvider() {
         return dataProvider;
     }
+
+    @Override
+    public void updateRenderedColumns() {
+        final boolean isAtLeastOneImportRemovable = getDataProvider().getList()
+                .stream()
+                .anyMatch(iType -> isExternalImport(iType) && !BuiltInTypeImportHelper.isBuiltIn(iType));
+
+        final int columnCount = table.getColumnCount();
+        if (isAtLeastOneImportRemovable && columnCount == 1) {
+            table.addColumn(deleteImportColumn,
+                            ImportConstants.INSTANCE.remove());
+        } else if (!isAtLeastOneImportRemovable && columnCount > 1) {
+            table.removeColumn(deleteImportColumn);
+        }
+    }
 }
